==> sped-1.35.26.tar.gz: sped-1.35.26/pythonsped/contribuicoes/blocos.py <==
# -*- coding: utf-8 -*-

from pythonsped.contribuicoes.bloco_0 import *
from pythonsped.contribuicoes.bloco_a import *
from pythonsped.contribuicoes.bloco_c import *
from pythonsped.contribuicoes.bloco_d import *
from pythonsped.contribuicoes.bloco_f import *
from pythonsped.contribuicoes.bloco_m import *
from pythonsped.contribuicoes.bloco_p import *
from pythonsped.contribuicoes.bloco_1 import *
from pythonsped.contribuicoes.bloco_9 import *


class bloco_arquivo(TrackedAttributesClass):
    """Classe do Blocos"""

    class registro_0000(TrackedAttributesClass):
        """
        REGISTRO 0000: : ABERTURA DO ARQUIVO DIGITAL E IDENTIFICAÇÃO DA PESSOA JURÍDICA
        Registro obrigatório e corresponde ao primeiro registro do arquivo.
        """
        _order = []

        def __init__(self):
            super(bloco_arquivo.registro_0000, self).__init__()
            self.REG = '0000'
            self.nivel_h = 0  # nível
            self.pai = ''
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.COD_VER = ''  # Código da versão do leiaute conforme a tabela 3.1.1
            self.TIPO_ESCRIT = ''  # Tipo de escrituração:0 - Original;1 – Retificadora.
            self.IND_SIT_ESP = ''  # Indicador de situação especial:0 - Abertura 1 - Cisão 2 - Fusão 3 - Incorporação 4 – Encerramento
            self.NUM_REC_ANTERIOR = ''
            self.DT_INI = ''  # Data inicial das informações contidas no arquivo - N
            self.DT_FIN = ''  # Data final das informações contidas no arquivo - N
            self.NOME = ''  # Nome empresarial do contribuinte: - C
            self.CNPJ = ''  # Número de inscrição do contribuinte -N
            self.UF = ''  # Sigla da unidade da federação -C
            self.COD_MUN = ''  # Código do município do domicílio fiscal -N
            self.SUFRAMA = ''  # Número de inscrição do contribuinte: -C
            self.IND_NAT_PJ = ''  # Indicador da natureza da pessoa jurídica: 00 – Pessoa jurídica em geral 01 – Sociedade cooperativa 02 – Entidade sujeita ao PIS/Pasep exclusivamente com base na Folha de Salários
            self.IND_ATIV = ''  # Indicador de tipo de atividade preponderante: 0 – Industrial ou equiparado a industrial; 1 – Prestador de serviços; 2 - Atividade de comércio; 3 – Atividade financeira; 4 – Atividade imobiliária; 9 – Outro
            self.registro_0001 = []
            self.registro_0990 = []
            self.registro_1001 = []
            self.registro_1990 = []
            self.registro_9001 = []
            self.registro_9990 = []
            self.registro_C001 = []
            self.registro_C990 = []
            self.registro_D001 = []
            self.registro_D990 = []
            self.registro_E001 = []
            self.registro_E990 = []
            self.registro_G001 = []
            self.registro_G990 = []
            self.registro_H001 = []
            self.registro_H990 = []
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_VER': {'tipo': 'N', 'tamanho': 3, 'fixa_tamanho': True},
                'TIPO_ESCRIT': {'tipo': 'N', 'tamanho': 1, 'fixa_tamanho': True},
                'IND_SIT_ESP': {'tipo': 'N', 'tamanho': 1, 'fixa_tamanho': True},
                'NUM_REC_ANTERIOR': {'tipo': 'C', 'tamanho': 41, 'fixa_tamanho': True},
                'DT_INI': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'DT_FIN': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'NOME': {'tipo': 'C', 'tamanho': 100, 'fixa_tamanho': False},
                'CNPJ': {'tipo': 'N', 'tamanho': 14, 'fixa_tamanho': True},
                'UF': {'tipo': 'C', 'tamanho': 2, 'fixa_tamanho': True},
                'COD_MUN': {'tipo': 'N', 'tamanho': 7, 'fixa_tamanho': True},
                'SUFRAMA': {'tipo': 'C', 'tamanho': 9, 'fixa_tamanho': True},
                'IND_NAT_PJ': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'IND_ATIV': {'tipo': 'N', 'tamanho': 1, 'fixa_tamanho': True}
            }
            self.fieldnames = ('REG', 'COD_VER', 'TIPO_ESCRIT', 'IND_SIT_ESP', 'NUM_REC_ANTERIOR',
                               'DT_INI', 'DT_FIN', 'NOME', 'CNPJ', 'UF', 'COD_MUN', 'SUFRAMA',
                               'IND_NAT_PJ', 'IND_ATIV')
            self.formato = self.get_formato()

    def monta_arquivo(self, caminho='/tmp/', salvar_disco=False):
        # Escrevendo blocos totalizadores

        main = TrackedAttributesClass()

        reg_0990 = bloco_0.registro_0990()
        reg_0990.QTD_LIN_0 = main.conta_registro['bloco_0'] + 1
        reg_0990.write_line()

        reg_A990 = bloco_a.registro_A990()
        reg_A990.QTD_LIN_A = main.conta_registro['bloco_a'] + 1
        reg_A990.write_line()

        reg_C990 = bloco_c.registro_C990()
        reg_C990.QTD_LIN_C = main.conta_registro['bloco_c'] + 1
        reg_C990.write_line()

        reg_D990 = bloco_d.registro_D990()
        reg_D990.QTD_LIN_D = main.conta_registro['bloco_d'] + 1
        reg_D990.write_line()

        reg_F990 = bloco_f.registro_F990()
        reg_F990.QTD_LIN_F = main.conta_registro['bloco_f'] + 1
        reg_F990.write_line()

        reg_M990 = bloco_m.registro_M990()
        reg_M990.QTD_LIN_M = main.conta_registro['bloco_m'] + 1
        reg_M990.write_line()

        reg_P990 = bloco_p.registro_P990()
        reg_P990.QTD_LIN_P = main.conta_registro['bloco_p'] + 1
        reg_P990.write_line()

        reg_1990 = bloco_1.registro_1990()
        reg_1990.QTD_LIN_1 = main.conta_registro['bloco_1'] + 1
        reg_1990.write_line()

        linhas_arquivo = 0
        qt_9900 = 0
        qt_registros = main.quantidade_registros.copy()
        qt_registros['9990'] = 1
        for x in qt_registros:  #lançando totais de registros no registro 9900
            reg_9900 = bloco_9.registro_9900()
            reg_9900.REG_BLC = x
            reg_9900.QTD_REG_BLC = qt_registros[x]
            reg_9900.write_line()
            linhas_arquivo += qt_registros[x]
            qt_9900 += 1

        reg_9900 = bloco_9.registro_9900()
        reg_9900.REG_BLC = '9900'
        reg_9900.QTD_REG_BLC = qt_9900 + 2
        reg_9900.write_line()

        reg_9900 = bloco_9.registro_9900()
        reg_9900.REG_BLC = '9999'
        reg_9900.QTD_REG_BLC = 1
        reg_9900.write_line()
        #        #quantidade de registros do bloco 9
        reg_9990 = bloco_9.registro_9990()
        reg_9990.QTD_LIN_9 = qt_9900 + 5
        reg_9990.write_line()
        #fechamento do arquivo
        reg_9999 = bloco_9.registro_9999()
        reg_9999.QTD_LIN = linhas_arquivo + qt_9900 + 3
        reg_9999.write_line()

        #abrindo e fechando arquivo 0000/9999

        bloc_0, bloc_a, bloc_c, bloc_d, bloc_f, bloc_m, bloc_p, bloc_1, bloc_9 = [], [], [], [], [], [], [], [], []

        for r in main.processos:
            if r.startswith('|0'):
                bloc_0.append(r)  #adiciona todos os registros instanciados do bloco 0 em primeiro nivel
            if r.startswith('|A'):
                bloc_a.append(r)
            if r.startswith('|C'):
                bloc_c.append(r)
            if r.startswith('|D'):
                bloc_d.append(r)
            if r.startswith('|F'):
                bloc_f.append(r)
            if r.startswith('|M'):
                bloc_m.append(r)
            if r.startswith('|P'):
                bloc_p.append(r)
            if r.startswith('|1'):
                bloc_1.append(r)
            if r.startswith('|9'):
                bloc_9.append(r)
                bloc_9.sort()
        proc = bloc_0 + bloc_a + bloc_c + bloc_d + bloc_f + bloc_m + bloc_p + bloc_1 + bloc_9
        result = ''.join(proc)
        #esvaziando informações
        main.processos[:] = []
        main.quantidade_registros.clear()
        main.conta_registro.clear()
        main.conta_registro['bloco_0'] = 0
        main.conta_registro['bloco_a'] = 0
        main.conta_registro['bloco_c'] = 0
        main.conta_registro['bloco_d'] = 0
        main.conta_registro['bloco_f'] = 0
        main.conta_registro['bloco_m'] = 0
        main.conta_registro['bloco_p'] = 0
        main.conta_registro['bloco_1'] = 0
        main.conta_registro['bloco_9'] = 0
        return result

==> sped-3.0.4.tar.gz: sped-3.0.4/pythonsped/contribuicoes/blocos.py <==
# -*- coding: utf-8 -*-

from .bloco_0 import *
from .bloco_a import *
from .bloco_c import *
from .bloco_d import *
from .bloco_f import *
from .bloco_m import *
from .bloco_p import *
from .bloco_1 import *
from .bloco_9 import *


class bloco_arquivo(TrackedAttributesClass):
    """Classe do Blocos"""

    class registro_0000(TrackedAttributesClass):
        """
        REGISTRO 0000: : ABERTURA DO ARQUIVO DIGITAL E IDENTIFICAÇÃO DA PESSOA JURÍDICA
        Registro obrigatório e corresponde ao primeiro registro do arquivo.
        """
        _order = []

        def __init__(self):
            super(bloco_arquivo.registro_0000, self).__init__()
            self.REG = '0000'
            self.nivel_h = 0  # nível
            self.pai = ''
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.COD_VER = ''  # Código da versão do leiaute conforme a tabela 3.1.1
            self.TIPO_ESCRIT = ''  # Tipo de escrituração:0 - Original;1 – Retificadora.
            self.IND_SIT_ESP = ''  # Indicador de situação especial:0 - Abertura 1 - Cisão 2 - Fusão 3 - Incorporação 4 – Encerramento
            self.NUM_REC_ANTERIOR = ''
            self.DT_INI = ''  # Data inicial das informações contidas no arquivo - N
            self.DT_FIN = ''  # Data final das informações contidas no arquivo - N
            self.NOME = ''  # Nome empresarial do contribuinte: - C
            self.CNPJ = ''  # Número de inscrição do contribuinte -N
            self.UF = ''  # Sigla da unidade da federação -C
            self.COD_MUN = ''  # Código do município do domicílio fiscal -N
            self.SUFRAMA = ''  # Número de inscrição do contribuinte: -C
            self.IND_NAT_PJ = ''  # Indicador da natureza da pessoa jurídica: 00 – Pessoa jurídica em geral 01 – Sociedade cooperativa 02 – Entidade sujeita ao PIS/Pasep exclusivamente com base na Folha de Salários
            self.IND_ATIV = ''  # Indicador de tipo de atividade preponderante: 0 – Industrial ou equiparado a industrial; 1 – Prestador de serviços; 2 - Atividade de comércio; 3 – Atividade financeira; 4 – Atividade imobiliária; 9 – Outro
            self.registro_0001 = []
            self.registro_0990 = []
            self.registro_1001 = []
            self.registro_1990 = []
            self.registro_9001 = []
            self.registro_9990 = []
            self.registro_C001 = []
            self.registro_C990 = []
            self.registro_D001 = []
            self.registro_D990 = []
            self.registro_E001 = []
            self.registro_E990 = []
            self.registro_G001 = []
            self.registro_G990 = []
            self.registro_H001 = []
            self.registro_H990 = []
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_VER': {'tipo': 'N', 'tamanho': 3, 'fixa_tamanho': True},
                'TIPO_ESCRIT': {'tipo': 'N', 'tamanho': 1, 'fixa_tamanho': True},
                'IND_SIT_ESP': {'tipo': 'N', 'tamanho': 1, 'fixa_tamanho': True},
                'NUM_REC_ANTERIOR': {'tipo': 'C', 'tamanho': 41, 'fixa_tamanho': True},
                'DT_INI': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'DT_FIN': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'NOME': {'tipo': 'C', 'tamanho': 100, 'fixa_tamanho': False},
                'CNPJ': {'tipo': 'N', 'tamanho': 14, 'fixa_tamanho': True},
                'UF': {'tipo': 'C', 'tamanho': 2, 'fixa_tamanho': True},
                'COD_MUN': {'tipo': 'N', 'tamanho': 7, 'fixa_tamanho': True},
                'SUFRAMA': {'tipo': 'C', 'tamanho': 9, 'fixa_tamanho': True},
                'IND_NAT_PJ': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'IND_ATIV': {'tipo': 'N', 'tamanho': 1, 'fixa_tamanho': True}
            }
            self.fieldnames = ('REG', 'COD_VER', 'TIPO_ESCRIT', 'IND_SIT_ESP', 'NUM_REC_ANTERIOR',
                               'DT_INI', 'DT_FIN', 'NOME', 'CNPJ', 'UF', 'COD_MUN', 'SUFRAMA',
                               'IND_NAT_PJ', 'IND_ATIV')
            self.formato = self.get_formato()

    def monta_arquivo(self, caminho='/tmp/', salvar_disco=False):
        # Escrevendo blocos totalizadores

        main = TrackedAttributesClass()

        reg_0990 = bloco_0.registro_0990()
        reg_0990.QTD_LIN_0 = main.conta_registro['bloco_0'] + 1
        reg_0990.write_line()

        reg_A990 = bloco_a.registro_A990()
        reg_A990.QTD_LIN_A = main.conta_registro['bloco_a'] + 1
        reg_A990.write_line()

        reg_C990 = bloco_c.registro_C990()
        reg_C990.QTD_LIN_C = main.conta_registro['bloco_c'] + 1
        reg_C990.write_line()

        reg_D990 = bloco_d.registro_D990()
        reg_D990.QTD_LIN_D = main.conta_registro['bloco_d'] + 1
        reg_D990.write_line()

        reg_F990 = bloco_f.registro_F990()
        reg_F990.QTD_LIN_F = main.conta_registro['bloco_f'] + 1
        reg_F990.write_line()

        reg_M990 = bloco_m.registro_M990()
        reg_M990.QTD_LIN_M = main.conta_registro['bloco_m'] + 1
        reg_M990.write_line()

        reg_P990 = bloco_p.registro_P990()
        reg_P990.QTD_LIN_P = main.conta_registro['bloco_p'] + 1
        reg_P990.write_line()

        reg_1990 = bloco_1.registro_1990()
        reg_1990.QTD_LIN_1 = main.conta_registro['bloco_1'] + 1
        reg_1990.write_line()

        linhas_arquivo = 0
        qt_9900 = 0
        qt_registros = main.quantidade_registros.copy()
        qt_registros['9990'] = 1
        for x in qt_registros:  #lançando totais de registros no registro 9900
            reg_9900 = bloco_9.registro_9900()
            reg_9900.REG_BLC = x
            reg_9900.QTD_REG_BLC = qt_registros[x]
            reg_9900.write_line()
            linhas_arquivo += qt_registros[x]
            qt_9900 += 1

        reg_9900 = bloco_9.registro_9900()
        reg_9900.REG_BLC = '9900'
        reg_9900.QTD_REG_BLC = qt_9900 + 2
        reg_9900.write_line()

        reg_9900 = bloco_9.registro_9900()
        reg_9900.REG_BLC = '9999'
        reg_9900.QTD_REG_BLC = 1
        reg_9900.write_line()
        #        #quantidade de registros do bloco 9
        reg_9990 = bloco_9.registro_9990()
        reg_9990.QTD_LIN_9 = qt_9900 + 5
        reg_9990.write_line()
        #fechamento do arquivo
        reg_9999 = bloco_9.registro_9999()
        reg_9999.QTD_LIN = linhas_arquivo + qt_9900 + 3
        reg_9999.write_line()

        #abrindo e fechando arquivo 0000/9999

        bloc_0, bloc_a, bloc_c, bloc_d, bloc_f, bloc_m, bloc_p, bloc_1, bloc_9 = [], [], [], [], [], [], [], [], []

        for r in main.processos:
            if r.startswith('|0'):
                bloc_0.append(r)  #adiciona todos os registros instanciados do bloco 0 em primeiro nivel
            if r.startswith('|A'):
                bloc_a.append(r)
            if r.startswith('|C'):
                bloc_c.append(r)
            if r.startswith('|D'):
                bloc_d.append(r)
            if r.startswith('|F'):
                bloc_f.append(r)
            if r.startswith('|M'):
                bloc_m.append(r)
            if r.startswith('|P'):
                bloc_p.append(r)
            if r.startswith('|1'):
                bloc_1.append(r)
            if r.startswith('|9'):
                bloc_9.append(r)
                bloc_9.sort()
        proc = bloc_0 + bloc_a + bloc_c + bloc_d + bloc_f + bloc_m + bloc_p + bloc_1 + bloc_9
        result = ''.join(proc)
        #esvaziando informações
        main.processos[:] = []
        main.quantidade_registros.clear()
        main.conta_registro.clear()
        main.conta_registro['bloco_0'] = 0
        main.conta_registro['bloco_a'] = 0
        main.conta_registro['bloco_c'] = 0
        main.conta_registro['bloco_d'] = 0
        main.conta_registro['bloco_f'] = 0
        main.conta_registro['bloco_m'] = 0
        main.conta_registro['bloco_p'] = 0
        main.conta_registro['bloco_1'] = 0
        main.conta_registro['bloco_9'] = 0
        return result
